@@ -2,12 +2,12 @@ print.bab <- function(x, ...){
   rval <- as.data.frame(rbind(x$dobs, x$phat, x$mcse))
   rownames(rval) <- c("observed.stat", "pvalue", "mcse")
   colnames(rval) <- x$stat(rowlabels = TRUE)
-  print(rval)
+  rval
 }
 
 print.cab <- function(x, ...){
   rval <- as.data.frame(rbind(x$dobs, x$phat, x$mcse))
   rownames(rval) <- c("observed.stat", "pvalue", "mcse")
   colnames(rval) <- x$stat(rowlabels = TRUE)
-  print(rval)
+  rval
 }
